@@ -12,7 +12,7 @@ class Orthography(models.Model):
 class Trigram(caching.base.CachingMixin, models.Model):
     word = models.ForeignKey(Orthography,related_name='word')
     word_i_minus_one = models.ForeignKey(Orthography,related_name='word_i_minus_one')
-    word_i_minus_two = models.ForeignKey(Orthography,related_name='word_i_minus_one')
+    word_i_minus_two = models.ForeignKey(Orthography,related_name='word_i_minus_two')
     count = models.IntegerField()
 
     objects = caching.base.CachingManager()
