@@ -17,14 +17,15 @@ def in_trigram_context_entropy(wordOne,wordTwo):
     w_two_contexts.update({x:0 for x in w_one_contexts if x not in w_two_contexts})
     #print(w_one_contexts)
     #print(w_two_contexts)
-
+    #print w_one_contexts
+    #print w_two_contexts
     c_w_one = sum([x.count for x in w_one])
     c_w_two = sum([x.count for x in w_two])
     #print(c_w_one)
     #print(c_w_two)
-    context_ent = [entropy_calc(c_w_one,c_w_two,
-                                w_one_contexts[x],w_two_contexts[x]) for x in w_one_contexts]
-
+    context_ent = [entropy_calc(float(c_w_one),float(c_w_two),
+                                float(w_one_contexts[x]),float(w_two_contexts[x])) for x in w_one_contexts]
+    #print context_ent
     #print(context_ent)
     context_sum = sum(context_ent)
     #print(context_sum)
@@ -32,6 +33,10 @@ def in_trigram_context_entropy(wordOne,wordTwo):
 
 
 def entropy_calc(cntOne,cntTwo,cntCOne,cntCTwo):
+    #print cntOne
+    #print cntTwo
+    #print cntCOne
+    #print cntCTwo
     pCGivenWords = (cntCOne + cntCTwo)/(cntOne + cntTwo)
     Entp = cntCOne / (cntCOne + cntCTwo)
     if Entp == 0.0:
